from gravithon.units.length import meter
from gravithon.units.mass import kilogram
from gravithon.units.time import second

G = gravitational_constant = 6.6743 * 10 ** -11 * (meter ** 3) * (kilogram ** -1) * (second ** -2)
c = speed_of_light = 299792458 * (meter / second)
# TODO: more constants
