from gravithon.units.prefixes import *

# MKS units
m = meter = 1

dm = decimeter = deca * meter
hm = hectometer = hecto * meter
km = kilometer = kilo * meter

cm = centimeter = centi * meter
mm = millimeter = milli * meter
μm = micrometer = micro * meter
nm = nanometer = nano * meter

# US units
inch = 0.0254 * meter

ft = foot = 12 * inch
yd = yard = 36 * inch
