from gravithon.units.prefixes import *

# MKS units
kg = kilogram = 1
g = gram = kilogram * (10 ** -3)

t = tonne = 1000 * kg

mg = milligram = milli * gram
μg = microgram = micro * gram
ng = nanogram = nano * gram
